@echo off

rem ************************************************************************
rem * This file is part of Koala.                                          *
rem *                                                                      *
rem * Koala is free software: you can redistribute it and/or modify        *
rem * it under the terms of the GNU General Public License as published by *
rem * the Free Software Foundation, either version 3 of the License, or    *
rem * (at your option) any later version.                                  *
rem *                                                                      *
rem * Koala is distributed in the hope that it will be useful,             *
rem * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
rem * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
rem * GNU General Public License for more details.                         *
rem *                                                                      *
rem * You should have received a copy of the GNU General Public License    *
rem * along with Koala.  If not, see <http://www.gnu.org/licenses/>.       *
rem ************************************************************************


rem **********************************
rem * Obtain Koala set-up parameters *
rem **********************************

set HOST=
set DBSVR=
set DBNAME=
set DBUSR=
set DBPW=
set KUSR=
set KPW=
set HTDOCS=
set HTPASSWD=
set MYSQL_BIN=
set PTUSER=
set PTOOLS_BIN_HTML=

rem ********************************
rem * Set customized install paths *
rem ********************************
echo Install paths
echo -------------
echo Just press enter for these if you have followed
echo the Koala installation instructions for each
echo pre-requisite, using our installers.
echo.

:regethtdocs
set /p HTDOCS="Path for Apache's htdocs [%PROGRAMFILES%\Apache Software Foundation\Apache2.2\htdocs]: "
if [%HTDOCS%]==[] set "HTDOCS=%PROGRAMFILES%\Apache Software Foundation\Apache2.2\htdocs"
if not exist "%HTDOCS%" (
    echo INVALID PATH - the path you entered '%HTDOCS%' does not exists
    Goto regethtdocs
)
goto regethtpasswd

:regethtpasswd
set /p HTPASSWD="Path for Apache's htpasswd.exe [%PROGRAMFILES%\Apache Software Foundation\Apache2.2\bin\htpasswd.exe]: "
if [%HTPASSWD%]==[] set "HTPASSWD=%PROGRAMFILES%\Apache Software Foundation\Apache2.2\bin\htpasswd.exe"
if not exist "%HTPASSWD%" (
    echo INVALID PATH - the path you entered '%HTPASSWD%' does not exists
    Goto regethtpasswd
)
goto regetmysql

:regetmysql
set /p MYSQL_BIN="Path for MySQL's executable (mysql.exe) [%PROGRAMFILES%\MySQL\MySQL Server 5.5\bin\mysql.exe]: "
if [%MYSQL_BIN%]==[] set "MYSQL_BIN=%PROGRAMFILES%\MySQL\MySQL Server 5.5\bin\mysql.exe"
"%MYSQL_BIN%" --help > NUL
if "%ERRORLEVEL%" EQU "0" (
    goto regetptuser
) else (
    echo INVALID PATH - the path you entered '%MYSQL_BIN%' does not exists
    Goto regetmysql
)

:regetptuser
set /p PTUSER="Path for Pathway Tools' local user directory [%APPDATA%\ptools-local]: "
if [%PTUSER%]==[] set "PTUSER=%APPDATA%\ptools-local"
if not exist "%PTUSER%" (
    echo INVALID PATH - the path you entered '%PTUSER%' does not exists
    Goto regetptuser
)
goto startinstall

:startinstall
echo.
echo Koala setup
echo -----------
set /p HOST="The hostname for the current computer [localhost]: "
if [%HOST%]==[] set HOST=localhost

:redodb
set /p DBSVR="The hostname for the database server [localhost]: "
if [%DBSVR%]==[] set DBSVR=localhost

set /p DBNAME="The database name for koala [koala]: "
if [%DBNAME%]==[] set DBNAME=koala

set /p DBUSR="The database username for Koala [koala]: "
if [%DBUSR%]==[] set DBUSR=koala

:enterdbpw
set /p DBPW="The database password for Koala: "
if [%DBPW%]==[] Goto enterdbpw

echo select 0 | "%MYSQL_BIN%" %DBNAME% -h%DBSVR% -u%DBUSR% -p%DBPW% > NUL
if "%ERRORLEVEL%" EQU "0" (
    goto dbpwok
) else (
    echo Database password failed!
    echo Unable to connect to MySQL!
    echo Please re-enter your MySQL login informaton.
    goto redodb
)

:dbpwok
echo.
echo Create a new Koala account:
echo ---------------------------

set /p KUSR="The administrator username for Koala [koala]: "
if [%KUSR%]==[] set KUSR=koala

:enterkpw
set /p KPW="The administrator password for Koala: "
if [%KPW%]==[] Goto enterkpw
goto kpwok

:kpwok

rem **********************************
rem * Start the installation process *
rem **********************************
echo.
echo Starting installation
echo ---------------------

rem **************************
rem * Koala DB configuration *
rem **************************

echo updating database
"%MYSQL_BIN%" %DBNAME% -h%DBSVR% -u%DBUSR% -p%DBPW% < koala.sql

rem ******************************
rem * Koala Biocyc configuration *
rem ******************************

echo copying pathway tools files

if not exist "%PTUSER%\html\" mkdir "%PTUSER%\html\"

rem copy the Koala mascot image to the pathway tools local web directory
copy "koala-biocyc\animated-gifs-koala-bears-19.gif" "%PTUSER%\html\"

rem set the proper hosts for the pathway tools local web files
minised "s/localhost/%HOST%/" koala-biocyc\temporary-message.shtml     > "%PTUSER%\html\temporary-message.shtml"
minised "s/localhost/%HOST%/" koala-biocyc\userWebsiteCustomization.js > "%PTUSER%\html\userWebsiteCustomization.js"

rem create parameters
set "PTOOLS_INIT=%PTUSER%\ptools-init.dat"

IF NOT EXIST "%PTOOLS_INIT%" goto makeptoolsinit

:updateptoolsinit
echo updating pathway tools configuration
rem quote the pathway tools local html path for regular expression replacement
echo %PTUSER%\html | minised "s/[\\]/\\\\/g" > ptools_path
set /p PTOOLS_HTML=<ptools_path

findstr /I WWW-Html-Root-Dir "%PTOOLS_INIT%" > NUL
if "%ERRORLEVEL%" NEQ "0" goto getptoolsbin

:haswwwroot
rem update an existing ptools-init.dat file
rem add the local htmldocs to pathway tools' web search path
minised "s/###WWW-Html-Root-Dir/WWW-Html-Root-Dir/" > .\ptools-init.tmp < "%PTOOLS_INIT%"
minised "s/WWW-Html-Root-Dir /WWW-Html-Root-Dir %PTOOLS_HTML%+/" < .\ptools-init.tmp > "%PTOOLS_INIT%"

findstr /I WWW-Server-Port "%PTOOLS_INIT%" > NUL
if "%ERRORLEVEL%" NEQ "0" echo WWW-Server-Port 1555 >> "%PTOOLS_INIT%"

findstr /I WWW-Server-Hostname "%PTOOLS_INIT%" > NUL
if "%ERRORLEVEL%" NEQ "0" echo WWW-Server-Hostname %HOST% >> "%PTOOLS_INIT%"

echo deleting temporary files
del ptools_path
del ptools-init.tmp
goto doneptoolsinit

:makeptoolsinit
echo creating a new pathway tools configuration

:getptoolsbin
rem create a new ptools-init.dat file
set /p PTOOLS_BIN_HTML="Path for Pathway Tools root HTML directory [%PROGRAMFILES%\Pathway Tools\aic-export\htdocs]: "
if [%PTOOLS_BIN_HTML%]==[] set "PTOOLS_BIN_HTML=%PROGRAMFILES%\Pathway Tools\aic-export\htdocs"
if not exist "%PTOOLS_BIN_HTML%" (
    echo INVALID PATH - the path you entered '%PTOOLS_BIN_HTML%' does not exists
    Goto getptoolsbin
)
goto makeptoolsinit

:makeptoolsinit
echo WWW-Server-Port 1555 >> "%PTOOLS_INIT%"
echo WWW-Server-Hostname %HOST% >> "%PTOOLS_INIT%"
echo WWW-Html-Root-Dir %PTUSER%\html+%PTOOLS_BIN_HTML% >> "%PTOOLS_INIT%"

echo deleting temporary files
del ptools_path
goto doneptoolsinit

:doneptoolsinit

rem ******************************
rem * Koala Apache configuration *
rem ******************************

echo installing apache portion of Koala

rem make a Koala directory for Apache installation
mkdir "%HTDOCS%\koala"

rem copy all files to the apache home directory
xcopy /Y /S koala-apache\*.* "%HTDOCS%\koala"

rem create a new globals file - to store the database connection settings
minised "s/localhost/%DBSVR%/" koala-apache\globals.php | minised "s/NAME', 'koala/NAME', '%DBNAME%/" | minised "s/USER', 'koala/USER', '%DBUSR%/" | minised "s/abcdefg/%DBPW%/" > "%HTDOCS%\koala\globals.php"

echo %HTDOCS%\koala\.htpasswd | minised "s/[\\]/\\\\/g" > htpw_path
set /p HTPW=<htpw_path
del htpw_path

echo creating a new globals file - to store the database connection settings
minised "s/koala_path\/.htpasswd/%HTPW%/" koala-apache\.htaccess > "%HTDOCS%\koala\.htaccess"

"%HTPASSWD%" -bc "%HTDOCS%\koala\.htpasswd" %KUSR% %KPW%

echo Done installation
pause
